def addition(x=None, y=None):
    if x is not None and y is not None:
        return x+y
    else:
        return None


def subtraction(x=None, y=None):
    if x is not None and y is not None:
        return x-y
    else:
        return None


def multiplication(x=None, y=None):
    if x is not None and y is not None:
        return x*y
    else:
        return None


def division(x=None, y=None):
    if x is not None and y is not None:
        return x/y
    else:
        return None


def floor_division(x=None, y=None):
    if x is not None and y is not None:
        return x//y
    else:
        return None


def power(x=None, y=None):
    if x is not None and y is not None:
        return x**y
    else:
        return None
